﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using System.IO;

namespace GeoDatabaseTest
{
    public partial class TestUI : Form
    {
        public Object result = null;
        public string GDBPath = "";
        private InMemoryFeatureLayer memlayer;
        private string textColumnName = "";

        public TestUI()
        {
            InitializeComponent();
        }
        
        private void cmdCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void cmdOK_Click(object sender, EventArgs e)
        {
            this.Close();
        }
        
        private FeatureSource reproject_features(ManagedProj4Projection proj4, FeatureSource fsource)
        {
            if (!fsource.IsOpen) fsource.Open();
            if (!proj4.IsOpen) proj4.Open();
            if (!proj4.IsOpen) proj4.Open();
            Collection<Feature> fts= fsource.GetAllFeatures(ReturningColumnsType.AllColumns);
            //for (int i = 0; i < fts.Count; i++)
            //{
            //    Feature f = fts.ElementAt(i);
            //    f = proj4.ConvertToExternalProjection(f);
            //}
            FeatureSource fsource_out = new InMemoryFeatureSource(fsource.GetColumns());
            fsource_out.Open();
            fsource_out.BeginTransaction();
            for (int i = 0; i < fts.Count; i++)
            {
                Feature f = fts.ElementAt(i);               
                f = proj4.ConvertToInternalProjection(f);
                fsource_out.AddFeature(f);
            }
            fsource_out.CommitTransaction();
            fsource_out.Close();
            return fsource_out;
        }
        
        private void TestUI_Load(object sender, EventArgs e)
        {            
            GDBPath = Path.GetDirectoryName(Application.ExecutablePath);
            //GDBPath = Directory.GetParent(GDBPath) + "\\DB";
            label1.Text = GDBPath;

            foreach(string folder in Directory.GetDirectories(GDBPath,"*.gdb",SearchOption.TopDirectoryOnly))
            {
                listGDB.Items.Add(folder);
            }
            listGDB.SelectedIndex = 0;
            listTables.SelectedIndex = 0;
         
        }

        private void getTables()
        {
            Collection<string> tables = FileGeoDatabaseFeatureLayer.GetTableNames(listGDB.SelectedItem.ToString());
            listTables.Items.Clear();
            foreach (string table in tables)
            {
                listTables.Items.Add(table);
            }
        }

        private void listTables_SelectedIndexChanged(object sender, EventArgs e)
        {
            doGrid();
        }

        private void doGrid()
        {
            
            this.Cursor = Cursors.WaitCursor;
          
            FileGeoDatabaseFeatureLayer layer = new FileGeoDatabaseFeatureLayer(listGDB.SelectedItem.ToString(), listTables.SelectedItem.ToString());
            layer.Open();

            //***********************
            //this code produces same number of objects as doing "select * from Tablename"
            //***********************
            //Collection<Feature> fts = layer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns, 0);
            char[] charsToTrim = { '.', ' ', '\\' };
            DataTable table = layer.FeatureSource.ExecuteQuery("select * from " + listTables.SelectedItem.ToString().Trim(charsToTrim));
            dataGridView1.DataSource = table;            

            layer.Close();
            layer = null;
            this.Cursor = Cursors.Arrow;
        }

        private void dataGridView1_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            textColumnName = dataGridView1.Columns[e.ColumnIndex].HeaderText;
        }

        private void listGDB_SelectedIndexChanged(object sender, EventArgs e)
        {
            getTables();
        }
    }
}
